@@ -17,6 +17,7 @@ class OrderedSet(collections.OrderedDict, collections.abc.MutableSet):
     """
     Ordered set to enhance presentation of column names.
     """
+
     def __init__(self, v: Optional[Iterable] = None):
         collections.OrderedDict.__init__(self)
         if v is not None:
@@ -98,7 +99,7 @@ def ordered_intersect(a: Iterable, b: Iterable) -> OrderedSet:
 
 def ordered_union(a: Iterable, b: Iterable) -> OrderedSet:
     """
-    Untion of two iterables, ordered by a first, then b.
+    Union of two iterables, ordered by a first, then b.
     """
     a = OrderedSet(a)
     for v in b:
@@ -109,7 +110,7 @@ def ordered_union(a: Iterable, b: Iterable) -> OrderedSet:
 
 def ordered_diff(a: Iterable, b: Iterable) -> OrderedSet:
     """
-    a with b removed
+    a with b removed, a order preserved.
     """
     b = set(b)
     a = OrderedSet([v for v in a if v not in b])
