@@ -28,11 +28,14 @@ class PostgreSQLModel(data_algebra.db_model.DBModel):
     """
 
     def __init__(self):
+        op_replacements = data_algebra.db_model.db_default_op_replacements.copy()
+        op_replacements['log'] = 'LN'
         data_algebra.db_model.DBModel.__init__(
             self,
             identifier_quote='"',
             string_quote="'",
             sql_formatters=PostgreSQL_formatters,
+            op_replacements=op_replacements,
         )
 
 
