@@ -1,3 +1,8 @@
+
+"""
+SparkSQL adapter for the data algebra.
+"""
+
 import data_algebra.data_ops
 import data_algebra.db_model
 
@@ -36,8 +41,14 @@ def _sparksql_is_bad_expr(dbmodel, expression):
 
 
 # treat NaN as NULL, as Pandas has a hard time distinguishing the two
-def _sparksql_coalesce_expr(dbmodel, expression):
-    def coalesce_step(x):
+def _sparksql_coalesce_expr(dbmodel, expression) -> str:
+    """
+    Return coalesce expression.
+    """
+    def coalesce_step(x: str) -> str:
+        """
+        Return one caes of coalesce.
+        """
         assert isinstance(x, str)
         return f" WHEN ({x} IS NOT NULL) AND (NOT isNaN({x})) THEN {x} "
 
@@ -53,15 +64,45 @@ def _sparksql_coalesce_expr(dbmodel, expression):
     )
 
 
+def _sparksql_db_mapv(dbmodel, expression):
+    # https://spark.apache.org/docs/latest/sql-ref-syntax-qry-select-case.html
+    if_expr = dbmodel.expr_to_sql(expression.args[0], want_inline_parens=True)
+    mapping_dict = expression.args[1]
+    default_value_expr = dbmodel.expr_to_sql(
+        expression.args[2], want_inline_parens=True
+    )
+    terms = [
+        "WHEN ("
+        + if_expr
+        + " = "
+        + dbmodel.value_to_sql(k)
+        + ") THEN "
+        + dbmodel.value_to_sql(v)
+        for k, v in mapping_dict.value.items()
+    ]
+    if len(terms) <= 0:
+        return default_value_expr
+    res = "CASE " + " ".join(terms) + " ELSE " + default_value_expr + " END"
+    if isinstance(expression.args[2].value, float):
+        res = "DOUBLE(" + res + ")"
+    elif isinstance(expression.args[2].value, int):
+        res = "INT(" + res + ")"
+    return res
+
+
 # map from op-name to special SQL formatting code
 SparkSQL_formatters = {
     "___": lambda dbmodel, expression: str(expression.to_python()),
     "is_bad": _sparksql_is_bad_expr,
     "coalesce": _sparksql_coalesce_expr,
+    "mapv": _sparksql_db_mapv,
 }
 
 
 class SparkConnection:
+    """
+    Holder for spark conext and session as a connection (defines close).
+    """
     def __init__(self, *, spark_context, spark_session):
         assert have_Spark
         assert isinstance(spark_context, pyspark.context.SparkContext)
@@ -70,6 +111,9 @@ class SparkConnection:
         self.spark_session = spark_session
 
     def close(self):
+        """
+        Stop context and release reference to context and session.
+        """
         if self.spark_context is not None:
             self.spark_context.stop()  # probably only for local demos
             self.spark_context = None
@@ -121,10 +165,13 @@ class SparkSQLModel(data_algebra.db_model.DBModel):
                 raise ValueError("table " + table_name + " already exists")
             else:
                 self.drop_table(conn, table_name, check=False)
-        d_spark = conn.spark_session.createDataFrame(d)
-        # https://stackoverflow.com/a/57292987/6901725
-        d_spark.replace(float("nan"), None)  # to get coalesce effects (didn't work)
-        d_spark.createOrReplaceTempView(table_name)  # TODO: non-temps
+        try:
+            d_spark = conn.spark_session.createDataFrame(d)
+            # https://stackoverflow.com/a/57292987/6901725
+            # d_spark.replace(float("nan"), None)  # to get coalesce effects (didn't work)
+            d_spark.createOrReplaceTempView(table_name)  # TODO: non-temps
+        except Exception as ex:
+            raise ValueError("Spark problem inserting table, " + str(ex))
 
 
 cached_spark_context = None
