@@ -187,6 +187,25 @@ def _db_mapv(dbmodel, expression):
 
 
 def _db_maximum_expr(dbmodel, expression):
+    x_expr = dbmodel.expr_to_sql(expression.args[0], want_inline_parens=True)
+    y_expr = dbmodel.expr_to_sql(expression.args[1], want_inline_parens=True)
+    return (
+        "CASE"
+        + " WHEN "
+        + "((" + y_expr + " IS NULL) OR "
+        + "(" + x_expr + ") >= (" + y_expr + "))"
+        + " THEN "
+        + x_expr
+        + " WHEN "
+        + "((" + x_expr + " IS NULL) OR "
+        + "(" + y_expr + ") >= (" + x_expr + "))"
+        + " THEN "
+        + y_expr
+        + " ELSE NULL END"
+    )
+
+
+def _db_fmax_expr(dbmodel, expression):
     x_expr = dbmodel.expr_to_sql(expression.args[0], want_inline_parens=True)
     y_expr = dbmodel.expr_to_sql(expression.args[1], want_inline_parens=True)
     return (
@@ -212,6 +231,25 @@ def _db_maximum_expr(dbmodel, expression):
 
 
 def _db_minimum_expr(dbmodel, expression):
+    x_expr = dbmodel.expr_to_sql(expression.args[0], want_inline_parens=True)
+    y_expr = dbmodel.expr_to_sql(expression.args[1], want_inline_parens=True)
+    return (
+        "CASE"
+        + " WHEN "
+        + "((" + y_expr + " IS NULL) OR "
+        + "(" + x_expr + ") <= (" + y_expr + "))"
+        + " THEN "
+        + x_expr
+        + " WHEN "
+        + "((" + x_expr + " IS NULL) OR "
+        + "(" + y_expr + ") <= (" + x_expr + "))"
+        + " THEN "
+        + y_expr
+        + " ELSE NULL END"
+    )
+
+
+def _db_fmin_expr(dbmodel, expression):
     x_expr = dbmodel.expr_to_sql(expression.args[0], want_inline_parens=True)
     y_expr = dbmodel.expr_to_sql(expression.args[1], want_inline_parens=True)
     return (
@@ -244,7 +282,11 @@ def _db_is_in_expr(dbmodel, expression):
 
 # noinspection PyUnusedLocal
 def _db_count_expr(dbmodel, expression):
-    return "SUM(1)"
+    """Count number of non-null entries (as in Pandas)"""
+    if len(expression.args) != 1:
+        return "SUM(1)"
+    e0 = dbmodel.expr_to_sql(expression.args[0], want_inline_parens=True)
+    return f"SUM(CASE WHEN {e0} IS NOT NULL THEN 1 ELSE 0 END)"
 
 
 def _db_concat_expr(dbmodel, expression):
@@ -294,6 +336,16 @@ def _db_ceil_expr(dbmodel, expression):
     )
 
 
+def _db_int_divide_expr(dbmodel, expression):
+    return (
+        "FLOOR("
+        + dbmodel.expr_to_sql(expression.args[0], want_inline_parens=True)
+        + " / "
+        + dbmodel.expr_to_sql(expression.args[1], want_inline_parens=True)
+        + ")"
+    )
+
+
 def _db_pow_expr(dbmodel, expression):
     return (
         "POWER("
@@ -480,13 +532,16 @@ db_expr_formatters = {
     "if_else": _db_if_else_expr,
     "is_in": _db_is_in_expr,
     "maximum": _db_maximum_expr,
+    "fmax": _db_fmax_expr,
     "minimum": _db_minimum_expr,
+    "fmin": _db_fmin_expr,
     "count": _db_count_expr,
     "concat": _db_concat_expr,
     "coalesce": _db_coalesce_expr,
     "round": _db_round_expr,
     "floor": _db_floor_expr,
     "ceil": _db_ceil_expr,
+    "//": _db_int_divide_expr,
     "**": _db_pow_expr,
     "nunique": _db_nunique_expr,
     "mapv": _db_mapv,
