@@ -17,19 +17,32 @@ class SQLWithList:
     """
     Carry an ordered sequence of SQL steps for use with a SQL WITH statement.
     """
-    def __init__(self, *, last_step: 'NearSQL', previous_steps: List[Tuple[str, 'NearSQLContainer']]):
+
+    def __init__(
+        self,
+        *,
+        last_step: "NearSQL",
+        previous_steps: List[Tuple[str, "NearSQLContainer"]],
+    ):
         assert isinstance(last_step, NearSQL)
         assert isinstance(previous_steps, List)
-        assert all([isinstance(vi, Tuple)
-                    and (len(vi) == 2)
-                    and isinstance(vi[0], str)
-                    and isinstance(vi[1], NearSQLContainer) for vi in previous_steps])
+        assert all(
+            [
+                isinstance(vi, Tuple)
+                and (len(vi) == 2)
+                and isinstance(vi[0], str)
+                and isinstance(vi[1], NearSQLContainer)
+                for vi in previous_steps
+            ]
+        )
         # check no table like entities in previous steps
         assert not any([v.near_sql.is_table for k, v in previous_steps])
         # check keying is unique
         previous_keys = {k for k, v in previous_steps}
         if len(previous_keys) != len(previous_steps):
-            assert len(previous_keys) == len(previous_steps)  # so we can set a breakpoint
+            assert len(previous_keys) == len(
+                previous_steps
+            )  # so we can set a breakpoint
         # check we are not coming up on a duplication
         if not last_step.is_table:
             assert last_step.quoted_query_name not in previous_keys
@@ -42,8 +55,23 @@ class NearSQL(ABC):
     Represent SQL queries in a mostly string-form
     """
 
-    def __init__(self, *, terms, quoted_query_name, is_table=False, annotation=None):
+    terms: Optional[dict]
+    query_name: Optional[str]
+    quoted_query_name: str
+    is_table: bool = False
+    annotation: Optional[str] = None
+
+    def __init__(
+        self,
+        *,
+        terms: Optional[dict],
+        query_name: Optional[str] = None,
+        quoted_query_name: str,
+        is_table: bool = False,
+        annotation: Optional[str] = None,
+    ):
         assert isinstance(terms, (dict, type(None)))
+        assert isinstance(query_name, (str, type(None)))
         assert isinstance(quoted_query_name, str)
         assert isinstance(is_table, bool)
         assert isinstance(annotation, (str, type(None)))
@@ -52,6 +80,7 @@ class NearSQL(ABC):
             assert isinstance(terms, dict)
             if len(terms) > 0:
                 self.terms = terms.copy()
+        self.query_name = query_name
         self.quoted_query_name = quoted_query_name
         self.is_table = is_table
         self.annotation = annotation
@@ -117,7 +146,9 @@ class NearSQLContainer:
 
     # sequence: a list where last element is a NearSQLContainer previous elements are (name, NearSQLContainer) pairs
     # stub the replacement common table expression in a NearSQLContainer
-    def to_with_form_stub(self) -> Tuple['NearSQLContainer', List[Tuple[str, 'NearSQLContainer']]]:
+    def to_with_form_stub(
+        self,
+    ) -> Tuple["NearSQLContainer", List[Tuple[str, "NearSQLContainer"]]]:
         if self.near_sql.is_table:
             return self, []
         in_with_form = self.near_sql.to_with_form()
@@ -126,16 +157,16 @@ class NearSQLContainer:
         if not stub.is_table:
             # replace step with a reference
             if stub.quoted_query_name not in {k for k, v in sequence}:
-                sequence.append((
-                    stub.quoted_query_name,
-                    NearSQLContainer(
-                        near_sql=stub,
-                        force_sql=self.force_sql,
+                sequence.append(
+                    (
+                        stub.quoted_query_name,
+                        NearSQLContainer(near_sql=stub, force_sql=self.force_sql,),
                     )
-                ))
+                )
             stub = NearSQLContainer(
                 near_sql=NearSQLCommonTableExpression(
-                    quoted_query_name=stub.quoted_query_name
+                    query_name=stub.query_name,
+                    quoted_query_name=stub.quoted_query_name,
                 ),
                 force_sql=self.force_sql,
             )
@@ -143,23 +174,35 @@ class NearSQLContainer:
 
 
 class NearSQLNamedEntity(NearSQL):
-    def __init__(self, *, terms, quoted_query_name):
+    def __init__(self, *, terms, query_name, quoted_query_name):
         NearSQL.__init__(
-            self, terms=terms, quoted_query_name=quoted_query_name, is_table=True,
+            self,
+            terms=terms,
+            query_name=query_name,
+            quoted_query_name=quoted_query_name,
+            is_table=True,
         )
 
     def to_with_form(self) -> SQLWithList:
         return SQLWithList(last_step=self, previous_steps=[])
 
-    def to_sql_str_list(self, *,
-                        columns=None, force_sql=False, constants=None, db_model, sql_format_options=None
-                        ) -> List[str]:
+    def to_sql_str_list(
+        self,
+        *,
+        columns=None,
+        force_sql=False,
+        constants=None,
+        db_model,
+        sql_format_options=None,
+    ) -> List[str]:
         raise NotImplementedError("abstract class method called")
 
 
 class NearSQLCommonTableExpression(NearSQLNamedEntity):
-    def __init__(self, *, quoted_query_name):
-        NearSQLNamedEntity.__init__(self, terms=None, quoted_query_name=quoted_query_name)
+    def __init__(self, *, query_name, quoted_query_name):
+        NearSQLNamedEntity.__init__(
+            self, terms=None, query_name=query_name, quoted_query_name=quoted_query_name
+        )
 
     def to_sql_str_list(
         self,
@@ -180,8 +223,14 @@ class NearSQLCommonTableExpression(NearSQLNamedEntity):
 
 
 class NearSQLTable(NearSQLNamedEntity):
-    def __init__(self, *, terms, quoted_query_name, quoted_table_name):
-        NearSQLNamedEntity.__init__(self, terms=terms, quoted_query_name=quoted_query_name)
+    def __init__(self, *, terms, table_name, quoted_table_name):
+        NearSQLNamedEntity.__init__(
+            self,
+            terms=terms,
+            query_name=table_name,
+            quoted_query_name=quoted_table_name,
+        )
+        self.table_name = table_name
         self.quoted_table_name = quoted_table_name
 
     def to_sql_str_list(
@@ -207,6 +256,7 @@ class NearSQLUnaryStep(NearSQL):
         self,
         *,
         terms,
+        query_name,
         quoted_query_name,
         sub_sql,
         suffix=None,
@@ -222,6 +272,7 @@ class NearSQLUnaryStep(NearSQL):
         NearSQL.__init__(
             self,
             terms=terms,
+            query_name=query_name,
             quoted_query_name=quoted_query_name,
             annotation=annotation,
         )
@@ -259,6 +310,7 @@ class NearSQLUnaryStep(NearSQL):
         stub, sequence = self.sub_sql.to_with_form_stub()
         stubbed_step = NearSQLUnaryStep(
             terms=self.terms,
+            query_name=self.query_name,
             quoted_query_name=self.quoted_query_name,
             sub_sql=stub,
             suffix=self.suffix,
@@ -272,6 +324,7 @@ class NearSQLBinaryStep(NearSQL):
         self,
         *,
         terms,
+        query_name,
         quoted_query_name,
         sub_sql1,
         joiner,
@@ -288,6 +341,7 @@ class NearSQLBinaryStep(NearSQL):
         NearSQL.__init__(
             self,
             terms=terms,
+            query_name=query_name,
             quoted_query_name=quoted_query_name,
             annotation=annotation,
         )
@@ -335,6 +389,7 @@ class NearSQLBinaryStep(NearSQL):
                 sequence.append(stepi)
         stubbed_step = NearSQLBinaryStep(
             terms=self.terms,
+            query_name=self.query_name,
             quoted_query_name=self.quoted_query_name,
             sub_sql1=stub1,
             joiner=self.joiner,
@@ -350,6 +405,7 @@ class NearSQLRawQStep(NearSQL):
         self,
         *,
         prefix: List[str],
+        query_name: str,
         quoted_query_name: str,
         sub_sql: Optional[NearSQLContainer],
         suffix: Optional[List[str]] = None,
@@ -360,6 +416,7 @@ class NearSQLRawQStep(NearSQL):
         assert isinstance(prefix, list)
         assert len(prefix) > 0
         assert all([isinstance(v, str) for v in prefix])
+        assert isinstance(query_name, str)
         assert isinstance(quoted_query_name, str)
         assert isinstance(sub_sql, (NearSQLContainer, type(None)))
         assert isinstance(suffix, (list, type(None)))
@@ -369,6 +426,7 @@ class NearSQLRawQStep(NearSQL):
         NearSQL.__init__(
             self,
             terms=None,  # not using this in this node
+            query_name=query_name,
             quoted_query_name=quoted_query_name,
             annotation=annotation,
         )
@@ -403,6 +461,7 @@ class NearSQLRawQStep(NearSQL):
         stub, sequence = self.sub_sql.to_with_form_stub()
         stubbed_step = NearSQLRawQStep(
             prefix=self.prefix,
+            query_name=self.query_name,
             quoted_query_name=self.quoted_query_name,
             sub_sql=stub,
             suffix=self.suffix,
