@@ -1,9 +1,9 @@
-
 """
 Basic utilities. Not allowed to import many other modules.
 """
 
 import datetime
+import warnings
 from typing import Dict, Iterable, Optional, Tuple
 
 import numpy
@@ -40,6 +40,7 @@ def pandas_to_example_str(obj, *, local_data_model=None) -> str:
 
 def table_is_keyed_by_columns(table, column_names: Iterable[str]) -> bool:
     """
+    Check if a table is keyed by a given list of column names.
 
     :param table: pandas DataFrame
     :param column_names: list of column names
@@ -63,58 +64,65 @@ def table_is_keyed_by_columns(table, column_names: Iterable[str]) -> bool:
 
 
 # noinspection PyBroadException
-def _mk_type_coversion_table():
-    type_conversions = dict()
+def _mk_type_conversion_table():
+    """
+    Build up conversion from type aliases we do not want into standard types. Eat any errors or warnings during table
+    construction.
+    """
+
+    type_conversions_table = dict()
     # DeprecationWarning: `np.bool` is a deprecated alias for the builtin `bool`.
     # To silence this warning, use `bool` by itself. Doing this will not modify any behavior and is safe.
     # If you specifically wanted the numpy scalar type, use `np.bool_` here.
     #   Deprecated in NumPy 1.20; for more details and guidance:
     #   https://numpy.org/devdocs/release/1.20.0-notes.html#deprecations
     # (note even numpy.bool_ triggers the above, or the triggering it is in pyspark right now
-    try:
-        type_conversions[numpy.bool_] = bool
-    except Exception:
-        pass
-    try:
-        type_conversions[numpy.bool] = bool
-    except Exception:
-        pass
-    try:
-        type_conversions[numpy.int] = int
-    except Exception:
-        pass
-    try:
-        type_conversions[numpy.int_] = int
-    except Exception:
-        pass
-    try:
-        type_conversions[numpy.int64] = int
-    except Exception:
-        pass
-    try:
-        type_conversions[numpy.float64] = float
-    except Exception:
-        pass
-    try:
-        type_conversions[numpy.float] = float
-    except Exception:
-        pass
-    try:
-        type_conversions[numpy.float_] = float
-    except Exception:
-        pass
-    try:
-        type_conversions[numpy.str] = str
-    except Exception:
-        pass
-    try:
-        type_conversions[numpy.str_] = str
-    except Exception:
-        pass
-    return type_conversions
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore")
+        try:
+            type_conversions_table[numpy.bool_] = bool
+        except Exception:
+            pass
+        try:
+            type_conversions_table[numpy.bool] = bool
+        except Exception:
+            pass
+        try:
+            type_conversions_table[numpy.int] = int
+        except Exception:
+            pass
+        try:
+            type_conversions_table[numpy.int_] = int
+        except Exception:
+            pass
+        try:
+            type_conversions_table[numpy.int64] = int
+        except Exception:
+            pass
+        try:
+            type_conversions_table[numpy.float64] = float
+        except Exception:
+            pass
+        try:
+            type_conversions_table[numpy.float] = float
+        except Exception:
+            pass
+        try:
+            type_conversions_table[numpy.float_] = float
+        except Exception:
+            pass
+        try:
+            type_conversions_table[numpy.str] = str
+        except Exception:
+            pass
+        try:
+            type_conversions_table[numpy.str_] = str
+        except Exception:
+            pass
+    return type_conversions_table
 
 
-type_conversions = _mk_type_coversion_table()
+type_conversions = _mk_type_conversion_table()
 
 
 def map_type_to_canonical(v: type) -> type:
@@ -141,22 +149,36 @@ def guess_carried_scalar_type(col) -> type:
     """
     # check for scalars first
     ct = map_type_to_canonical(type(col))
-    if ct in {str, int, float, bool, type(None), numpy.int64, numpy.float64,
-              datetime.datetime, datetime.date, datetime.timedelta}:
+    if ct in {
+        str,
+        int,
+        float,
+        bool,
+        type(None),
+        numpy.int64,
+        numpy.float64,
+        datetime.datetime,
+        datetime.date,
+        datetime.timedelta,
+    }:
         return ct
     # look at a list or Series
     if isinstance(col, data_algebra.default_data_model.pd.core.series.Series):
         col = col.values
     if len(col) < 1:
         return type(None)
-    good_idx = numpy.where(numpy.logical_not(data_algebra.default_data_model.pd.isna(col)))[0]
+    good_idx = numpy.where(
+        numpy.logical_not(data_algebra.default_data_model.pd.isna(col))
+    )[0]
     test_idx = 0
     if len(good_idx) > 0:
         test_idx = good_idx[0]
     return map_type_to_canonical(type(col[test_idx]))
 
 
-def guess_column_types(d, *, columns: Optional[Iterable[str]] = None) -> Dict[str, type]:
+def guess_column_types(
+    d, *, columns: Optional[Iterable[str]] = None
+) -> Dict[str, type]:
     """
     Guess column types as type of first non-missing value.
     Will not return series types, as some pandas data frames with non-trivial indexing report this type.
@@ -175,7 +197,11 @@ def guess_column_types(d, *, columns: Optional[Iterable[str]] = None) -> Dict[st
     res = dict()
     for c in columns:
         gt = guess_carried_scalar_type(d[c])
-        if (gt is None) or (not isinstance(gt, type)) or gt == data_algebra.default_data_model.pd.core.series.Series:
+        if (
+            (gt is None)
+            or (not isinstance(gt, type))
+            or gt == data_algebra.default_data_model.pd.core.series.Series
+        ):
             # pandas.concat() poisons types with Series, don't allow that
             return dict()
         res[c] = gt
@@ -195,8 +221,9 @@ def compatible_types(types_seen: Iterable[type]) -> bool:
     return True
 
 
-def check_columns_appear_compatible(d_left, d_right, *, columns: Optional[Iterable[str]] = None
-                                    ) -> Optional[Dict[str, Tuple[type, type]]]:
+def check_columns_appear_compatible(
+    d_left, d_right, *, columns: Optional[Iterable[str]] = None
+) -> Optional[Dict[str, Tuple[type, type]]]:
     """
     Check if columns have compatible types
 
